aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrGeometryBuffer.h
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /src/gpu/GrGeometryBuffer.h
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'src/gpu/GrGeometryBuffer.h')
-rw-r--r--src/gpu/GrGeometryBuffer.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gpu/GrGeometryBuffer.h b/src/gpu/GrGeometryBuffer.h
index adccbf80e4..56a6cae3fb 100644
--- a/src/gpu/GrGeometryBuffer.h
+++ b/src/gpu/GrGeometryBuffer.h
@@ -48,7 +48,7 @@ public:
* Note that buffer mapping does not go through GrContext and therefore is
* not serialized with other operations.
*
* @return a pointer to the data or NULL if the map fails.
*/
void* map() { return (fMapPtr = this->onMap()); }
@@ -60,14 +60,14 @@ public:
void unmap() {
SkASSERT(fMapPtr);
this->onUnmap();
- fMapPtr = NULL;
+ fMapPtr = nullptr;
}
/**
* Returns the same ptr that map() returned at time of map or NULL if the
* is not mapped.
*
* @return ptr to mapped buffer data or NULL if buffer is not mapped.
*/
void* mapPtr() const { return fMapPtr; }
@@ -101,7 +101,7 @@ public:
protected:
GrGeometryBuffer(GrGpu* gpu, size_t gpuMemorySize, bool dynamic, bool cpuBacked)
: INHERITED(gpu, kCached_LifeCycle)
- , fMapPtr(NULL)
+ , fMapPtr(nullptr)
, fGpuMemorySize(gpuMemorySize)
, fDynamic(dynamic)
, fCPUBacked(cpuBacked) {}
@@ -48,7 +48,7 @@ public:
* not serialized with other operations.
*
- * @return a pointer to the data or NULL if the map fails.
+ * @return a pointer to the data or nullptr if the map fails.
*/
void* map() { return (fMapPtr = this->onMap()); }
@@ -60,14 +60,14 @@ public:
}
/**
- * Returns the same ptr that map() returned at time of map or NULL if the
+ * Returns the same ptr that map() returned at time of map or nullptr if the
* is not mapped.
*
@@ -60,14 +60,14 @@ public:
* is not mapped.
*
- * @return ptr to mapped buffer data or NULL if buffer is not mapped.
+ * @return ptr to mapped buffer data or nullptr if buffer is not mapped.
*/
void* mapPtr() const { return fMapPtr; }